package com.bonus.material.basic.service;

import java.util.List;
import com.bonus.material.basic.domain.BmCompanyAddress;

/**
 * 企业信息Service接口
 * 
 * @author xsheng
 * @date 2024-12-16
 */
public interface IBmCompanyAddressService {
    /**
     * 查询企业信息
     * 
     * @param id 企业信息主键
     * @return 企业信息
     */
    public BmCompanyAddress selectBmCompanyAddressById(Long id);

    /**
     * 查询企业信息列表
     * 
     * @param bmCompanyAddress 企业信息
     * @return 企业信息集合
     */
    public List<BmCompanyAddress> selectBmCompanyAddressList(BmCompanyAddress bmCompanyAddress);

    /**
     * 新增企业信息
     * 
     * @param bmCompanyAddress 企业信息
     * @return 结果
     */
    public int insertBmCompanyAddress(BmCompanyAddress bmCompanyAddress);

    /**
     * 修改企业信息
     * 
     * @param bmCompanyAddress 企业信息
     * @return 结果
     */
    public int updateBmCompanyAddress(BmCompanyAddress bmCompanyAddress);

    /**
     * 批量删除企业信息
     * 
     * @param ids 需要删除的企业信息主键集合
     * @return 结果
     */
    public int deleteBmCompanyAddressByIds(Long[] ids);

    /**
     * 删除企业信息信息
     * 
     * @param id 企业信息主键
     * @return 结果
     */
    public int deleteBmCompanyAddressById(Long id);
}
